@@ -1,5 +1,5 @@
 #
-# $Id: nwparse.pl 26095 2014-08-28 16:27:59Z d3y133 $
+# $Id$
 #
 #
 # perl script to parse nwchem output files
@@ -142,13 +142,13 @@ foreach $filename (@FILES_TO_PARSE) {
 		$indx2 = $indx1 + 1;
 		$indx3 = $indx1 + 2;
 		if (! $quiet) {
-		    printf " %10s %10.4f %10.4f %10.4f\n", 
+		    printf " %10s %10.3f %10.3f %10.3f\n", 
 		           $atoms[$iatom], 
                            set_to_digits($coords[$indx1],4), 
                            set_to_digits($coords[$indx2],4), 
 		           set_to_digits($coords[$indx3],4) ;
 		}
-		printf FILE_OUTPUT " %10s %10.4f %10.4f %10.4f\n", 
+		printf FILE_OUTPUT " %10s %10.3f %10.3f %10.3f\n", 
 		       $atoms[$iatom], 
                        set_to_digits($coords[$indx1],4), 
                        set_to_digits($coords[$indx2],4), 
@@ -164,17 +164,17 @@ foreach $filename (@FILES_TO_PARSE) {
 		$indx2 = $indx1 + 1;
 		$indx3 = $indx1 + 2;
 		if (! $quiet) {
-		    printf " %10s %10.4f %10.4f %10.4f\n", 
+		    printf " %10s %10.3f %10.3f %10.3f\n", 
 		         $atoms[$iatom], 
-		         set_to_digits($grads[$indx1],4), 
-		         set_to_digits($grads[$indx2],4),
-  		         set_to_digits($grads[$indx3],4);
+		         set_to_digits($grads[$indx1],3), 
+		         set_to_digits($grads[$indx2],3),
+  		         set_to_digits($grads[$indx3],3);
 		}
-		printf FILE_OUTPUT " %10s %10.4f %10.4f %10.4f\n", 
+		printf FILE_OUTPUT " %10s %10.3f %10.3f %10.3f\n", 
 		         $atoms[$iatom], 
-		         set_to_digits($grads[$indx1],4), 
-		         set_to_digits($grads[$indx2],4),
-  		         set_to_digits($grads[$indx3],4);
+		         set_to_digits($grads[$indx1],3), 
+		         set_to_digits($grads[$indx2],3),
+  		         set_to_digits($grads[$indx3],3);
 	    }
 	    
 	    @atoms = ();
@@ -192,7 +192,7 @@ foreach $filename (@FILES_TO_PARSE) {
            # that come in a deterministic order.
            $sgroup = 1;
         }
-	if (/^ Frequency/ || /^ P.Frequency/){
+	if (/^ P.Frequency/){
 	    if ($debug) {print "\ndebug: $_";}
 	    @line_tokens = split(' ');
 	    $num_line_tokens = @line_tokens;
@@ -215,6 +215,27 @@ foreach $filename (@FILES_TO_PARSE) {
 	    }
 	    printf FILE_OUTPUT "\n";
 	}
+	if (/^1-e int/){
+	    if ($debug) {print "\ndebug: $_";}
+	    @line_tokens = split(' ');
+	    $num_line_tokens = @line_tokens;
+	    if ($debug) {
+		print "debug:line_tokens: @line_tokens \n";
+		print "debug:number     : $num_line_tokens \n";
+	    }
+	    if (! $quiet) {
+	    printf "%s %s ", @line_tokens[0], @line_tokens[1];
+	    printf "%5d%5d ", @line_tokens[2], @line_tokens[3];
+	    printf "  %16.8f", set_to_digits(@line_tokens[4],8);
+	    }
+	    printf FILE_OUTPUT "%s %s ", @line_tokens[0], @line_tokens[1];
+	    printf FILE_OUTPUT "%5d%5d ", @line_tokens[2], @line_tokens[3];
+	    printf FILE_OUTPUT "  %17.9f", set_to_digits(@line_tokens[4],9);
+	    if (! $quiet) {
+		printf "\n";
+	    }
+	    printf FILE_OUTPUT "\n";
+	}
 	if (/^  Root / && (/ singlet / || / triplet /)){
 	    if ($debug) {print "\ndebug: $_";}
 	    @line_tokens = split(' ');
@@ -285,13 +306,13 @@ foreach $filename (@FILES_TO_PARSE) {
 	    }
 #                                                    *** Assumes $itok was incremented above
 	    if (! $quiet) {
-		printf "%.4f\n", set_to_digits(@line_tokens[$itok],4);
+		printf "%.3f\n", set_to_digits(@line_tokens[$itok],3);
 	    }
-	    printf FILE_OUTPUT "%.4f\n", set_to_digits(@line_tokens[$itok],4);
+	    printf FILE_OUTPUT "%.2f\n", set_to_digits(@line_tokens[$itok],2);
 	}
         if (! $sgroup) {
 	if (/Total/ && /energy/) {
-	 if (/SCF/ || /DFT/ || /CCSD/ || /MP2/ || /MCSCF/ || /RIMP2/ || /RISCF/ || /BAND/ || /PAW/ || /PSPW/ ) {
+	 if (/SCF/ || /DFT/ || /CCSD/ || /MP2/ || /MCSCF/ || /RIMP2/ || /RISCF/ || /BAND/ || /PAW/ || /PSPW/ || /WFN1/ || /xTB/ ) {
 		if ($debug) {print "\ndebug: $_";}
 		@line_tokens = split(' ');
 		$num_line_tokens = @line_tokens;
@@ -337,7 +358,51 @@ foreach $filename (@FILES_TO_PARSE) {
 	    }
 	}
 	}
-	if (/Excitation energy/) {
+
+        if (!$sgroup) {
+          if (/\@GW/) {
+            if ($debug) {print "\ndebug: $_";}
+            @line_tokens = split(' ');
+            $num_line_tokens = @line_tokens;
+            if ($debug) {
+              print "debug:line_tokens: @line_tokens \n";
+              print "debug:number     : $num_line_tokens \n";
+            }
+            for($itok = 0; $itok <($num_line_tokens-2); $itok++){
+              if (! $quiet) {
+                printf "%s ", @line_tokens[$itok];
+              }
+              printf FILE_OUTPUT "%s ", @line_tokens[$itok];
+            }
+            if (!$quiet) {
+              printf "%.2f\n", set_to_digits(@line_tokens[$itok],2);
+            }
+            printf FILE_OUTPUT "%.2f\n", set_to_digits(@line_tokens[$itok],2);
+          }
+        }
+        if (!$sgroup) {
+	    if (/rt\_tddft/ && /Etot/) {
+            if ($debug) {print "\ndebug: $_";}
+            @line_tokens = split(' ');
+            $num_line_tokens = @line_tokens;
+            if ($debug) {
+              print "debug:line_tokens: @line_tokens \n";
+              print "debug:number     : $num_line_tokens \n";
+            }
+            for($itok = 0; $itok <($num_line_tokens-3); $itok++){
+              if (! $quiet) {
+                printf "%s ", @line_tokens[$itok];
+              }
+              printf FILE_OUTPUT "%s ", @line_tokens[$itok];
+            }
+            if (!$quiet) {
+              printf "%.4f\n", set_to_digits(@line_tokens[$itok],4);
+            }
+            printf FILE_OUTPUT "%.4f\n", set_to_digits(@line_tokens[$itok],4);
+          }
+        }
+
+	if (/Excitation energy/ || /Rotatory / || /IBO loc: largest element in /) {
 	    if ($debug) {print "\ndebug: $_";}
 	    @line_tokens = split(' ');
 	    $num_line_tokens = @line_tokens;
@@ -377,7 +442,7 @@ foreach $filename (@FILES_TO_PARSE) {
             }
             printf FILE_OUTPUT "%.10f\n", set_to_digits(@line_tokens[$itok],10);
         }
-	if (/isotropic =/ || /anisotropy =/) {
+	if (/isotropic =/ || /anisotropy =/ ) {
 		if ($debug) {print "\ndebug: $_";}
 		@line_tokens = split(' ');
 		$num_line_tokens = @line_tokens;
@@ -396,6 +461,27 @@ foreach $filename (@FILES_TO_PARSE) {
 		    printf "%.3f\n", set_to_digits(@line_tokens[$itok],3);
 		}
 		printf FILE_OUTPUT "%.3f\n", set_to_digits(@line_tokens[$itok],3);
+	}
+		if ( /average: /) {
+		if ($debug) {print "\ndebug: $_";}
+		@line_tokens = split(' ');
+		$num_line_tokens = @line_tokens;
+		if ($debug) {
+		    print "debug:line_tokens: @line_tokens \n";
+		    print "debug:number     : $num_line_tokens \n";
+		}
+		for($itok = 0;$itok < ($num_line_tokens-1); $itok++){
+		    if (! $quiet) {
+			printf "%s ", @line_tokens[$itok];
+		    }
+		    #printf FILE_OUTPUT "%s ", @line_tokens[$itok];
+		}
+#                                                    *** Assumes $itok was incremented above
+		if (! $quiet) {
+		    printf "%s %.3f %s %s %.3f\n", @line_tokens[0], 0+@line_tokens[1], @line_tokens[2], @line_tokens[3], 0+@line_tokens[4];
+		}
+		# zeros are added to avoid diffs resulting from -0.000 versus 0.000 after rounding 
+		printf FILE_OUTPUT "%s %.3f %s %s %.3f\n", @line_tokens[0], 0+@line_tokens[1], @line_tokens[2], @line_tokens[3], 0+@line_tokens[4];
 	}
 	if (/DMX/ || /DMY/ || /DMZ/ ) {
 		if ($debug) {print "\ndebug: $_";}
