@@ -1,5 +1,5 @@
 /*
- $Id: pdspeval.c 19708 2010-10-29 18:04:21Z d3y133 $
+ $Id$
  *======================================================================
  *
  * DISCLAIMER
@@ -59,7 +59,7 @@ void pdspeval ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
   
 /*
  *
- *  Our parallel version of LAPACK's dspevx.
+ *  Our parallel version of LAPACK's yspevx.
  *
  *
  *  Purpose
@@ -297,12 +297,12 @@ void pdspeval ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
 
     extern Integer  mapchk_(), count_list();
     extern void     memreq_();
-    extern void     pdiff(), xstop_(), pgexit(), mapdif_(), reduce_maps_();
+    extern void     pdiff(), xstop_(), pgexit(), mapdif_();
     extern void     mdiff1_(), mdiff2_(), bbcast00();
     extern void     mem_cpy();
     extern void     dshellsort_(), sorteig();
 
-    extern DoublePrecision dnrm2_();
+    extern DoublePrecision ynrm2_();
 
     extern Integer  tred2();
     extern void     pstebz_(), pstein32(), mxm25(), sfnorm();
@@ -655,9 +655,9 @@ void pdspeval ( ivector, irange, n, vecA, mapA, lb, ub, ilb, iub, abstol,
 
       if( mapA[0] ==me ) {
         isize = msize - 1;
-        vec[0] = sqrt((DoublePrecision) 2.e0 ) * dnrm2_( &isize, &ee[1], &IONE );
-        vec[1] = dnrm2_( &msize, dd, &IONE );
-        fnormT = dnrm2_( &ITWO, vec, &IONE );
+        vec[0] = sqrt((DoublePrecision) 2.e0 ) * ynrm2_( &isize, &ee[1], &IONE );
+        vec[1] = ynrm2_( &msize, dd, &IONE );
+        fnormT = ynrm2_( &ITWO, vec, &IONE );
 	
         ulp = DLAMCHE * DLAMCHB ;
 
