@@ -1,5 +1,5 @@
 /*
- $Id: pdspgvx.c 19708 2010-10-29 18:04:21Z d3y133 $
+ $Id$
  *======================================================================
  *
  * DISCLAIMER
@@ -62,7 +62,7 @@ void pdspgvx( ifact, ivector, irange, n, vecA, mapA, vecB, mapB,
 
 /*
  *
- *  A parallel version of LAPACK's dspgv, but extended to allow for
+ *  A parallel version of LAPACK's yspgv, but extended to allow for
  *  the computation of selected eigenvalues and, optionally, eigenvectors.
  *
  *
@@ -319,7 +319,6 @@ void pdspgvx( ifact, ivector, irange, n, vecA, mapA, vecB, mapB,
   extern Integer  mxmynd_(), mxnprc_();
   extern Integer  mapchk_(), count_list(), fil_mapvec_(), reduce_list2();
 
-  extern void     reduce_maps();
   extern void     xstop_(), pdiff();
   extern void     pgexit();
   extern void     mapdif_();
