@@ -1,6 +1,6 @@
 /*
- $Id: pstebz10.c 21489 2011-11-09 22:30:32Z d3y133 $
- *======================================================================dstebz
+ $Id$
+ *======================================================================ystebz
  *
  * DISCLAIMER
  *
@@ -151,7 +151,7 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
  *          matrix T is considered to split into a block diagonal
  *          matrix.  On exit, if INFO = 0, IBLOCK(i) specifies to which
  *          block (from 1 to the number of blocks) the eigenvalue EVAL(i)
- *          belongs.  (DSTEBZ may use the remaining N-NEIGVAL elements as
+ *          belongs.  (YSTEBZ may use the remaining N-NEIGVAL elements as
  *          workspace.)
  *
  *  ISPLIT  (output) INTEGER array, dimension (N)
@@ -203,7 +203,7 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
  *               In theory INFO = 2, 3, or 4 should never occur.  If they do occur
  *               then DSTEBZ3 failed to correctly compute the requested eigenvalues.
  *
- *               Note that DSTEBZ3 is a modification of LAPACK's DSTEBZ.  The
+ *               Note that DSTEBZ3 is a modification of LAPACK's YSTEBZ.  The
  *               modifications had to be made to avoid gettings INFOs like 3 and 4.
 
  bug fixed with new lapack code
@@ -242,7 +242,7 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
    extern Integer  mapchk_();
    extern void     xstop_(), pdiff(), pgexit();
    DoublePrecision eps, tmp;
-   extern void dsterf_();
+   extern void ysterf_();
    extern void peigs_tldlfact();
    extern DoublePrecision dlamch_();
 
@@ -615,7 +615,7 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
    
    if ( *info != 0 ) {
      if ( me == 0 )
-       printf(" PeIGS error from dstebz %d ...trying dsterf \n", (int)*info );
+       printf(" PeIGS error from ystebz %d ...trying ysterf \n", (int)*info );
 
      file = fopen(filename, "a+");
      fprintf(file, "info = %d \n", (int)linfo);
@@ -631,10 +631,10 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
      for (i = 0; i < msize; i++ )
        work[msize + i] = e[i];
      
-     dsterf_( &msize, &work[0], &work[msize+1], info);
+     ysterf_( &msize, &work[0], &work[msize+1], info);
      if ( *info != 0 ){
        if ( me == 0 )
-	 printf(" error from dsterf %d \n", (int)*info );
+	 printf(" error from ysterf %d \n", (int)*info );
      }
      eval[0] = work[0];
    }
@@ -684,11 +684,11 @@ void pstebz10_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
      for (i = 0; i < msize; i++ )
        work[msize + i] = e[i];
      
-     dsterf_( &msize, &work[0], &work[msize+1], info);
+     ysterf_( &msize, &work[0], &work[msize+1], info);
 
      if ( *info != 0 ){
        if ( me == 0 )
-	 printf(" error from dsterf %d \n", (int)*info );
+	 printf(" error from ysterf %d \n", (int)*info );
      }
      
      for (i = 0; i < msize; i++ ){
