@@ -1,5 +1,5 @@
 /*
- $Id: pstebz11.c 21489 2011-11-09 22:30:32Z d3y133 $
+ $Id$
  *======================================================================
  *
  * DISCLAIMR
@@ -57,7 +57,7 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
 {
   
   /*
-   *  Parallel version of LAPACK's DSTEBZ.
+   *  Parallel version of LAPACK's YSTEBZ.
    *
    *  This routine is directly callable from both FORTRAN and C.
    *  The documentation below always uses FORTRAN array indexing,
@@ -154,7 +154,7 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
  *          matrix T is considered to split into a block diagonal
  *          matrix.  On exit, if INFO = 0, IBLOCK(i) specifies to which
  *          block (from 1 to the number of blocks) the eigenvalue EVAL(i)
- *          belongs.  (DSTEBZ may use the remaining N-NEIGVAL elements as
+ *          belongs.  (YSTEBZ may use the remaining N-NEIGVAL elements as
  *          workspace.)
  *
  *  ISPLIT  (output) INTEGER array, dimension (N)
@@ -206,7 +206,7 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
  *               In theory INFO = 2, 3, or 4 should never occur.  If they do occur
  *               then DSTEBZ3 failed to correctly compute the requested eigenvalues.
  *
- *               Note that DSTEBZ3 is a modification of LAPACK's DSTEBZ.  The
+ *               Note that DSTEBZ3 is a modification of LAPACK's YSTEBZ.  The
  *               modifications had to be made to avoid gettings INFOs like 3 and 4.
 
  bug fixed with new lapack code
@@ -712,9 +712,9 @@ void pstebz11_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e, dplus, lplus, mapZ,
    
    
    if ( *info != 0 ) {
-     fprintf(stderr, " me = %d ifakeme=%d dlasq1 returned info = %d to pstebz \n",
+     fprintf(stderr, " me = %d ifakeme=%d ylasq1 returned info = %d to pstebz \n",
 	     (int)me, (int)ifakeme, (int)*info );
-     fprintf(stderr, " me = %d ifakeme=%d dlasq1 also returned neig= %d il=%d iu=%d \n",
+     fprintf(stderr, " me = %d ifakeme=%d ylasq1 also returned neig= %d il=%d iu=%d \n",
 	     (int)me, (int)ifakeme, (int)m, (int)il, (int)iu );
      *info = 1;
      exit(-30);
