@@ -1,5 +1,5 @@
 /*
- $Id: pstebz9.c 19708 2010-10-29 18:04:21Z d3y133 $
+ $Id$
  *======================================================================
  *
  * DISCLAIMER
@@ -54,7 +54,7 @@ void pstebz9_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e,
 {
   
 /*
- *  Parallel version of LAPACK's DSTEBZ.
+ *  Parallel version of LAPACK's YSTEBZ.
  *
  *  This routine is directly callable from both FORTRAN and C.
  *  The documentation below always uses FORTRAN array indexing,
@@ -151,7 +151,7 @@ void pstebz9_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e,
  *          matrix T is considered to split into a block diagonal
  *          matrix.  On exit, if INFO = 0, IBLOCK(i) specifies to which
  *          block (from 1 to the number of blocks) the eigenvalue EVAL(i)
- *          belongs.  (DSTEBZ may use the remaining N-NEIGVAL elements as
+ *          belongs.  (YSTEBZ may use the remaining N-NEIGVAL elements as
  *          workspace.)
  *
  *  ISPLIT  (output) INTEGER array, dimension (N)
@@ -203,7 +203,7 @@ void pstebz9_( job, n, lb, ub, jjjlb, jjjub, abstol, d, e,
  *               In theory INFO = 2, 3, or 4 should never occur.  If they do occur
  *               then DSTEBZ3 failed to correctly compute the requested eigenvalues.
  *
- *               Note that DSTEBZ3 is a modification of LAPACK's DSTEBZ.  The
+ *               Note that DSTEBZ3 is a modification of LAPACK's YSTEBZ.  The
  *               modifications had to be made to avoid gettings INFOs like 3 and 4.
  *
  */
@@ -747,7 +747,7 @@ JUNK:
       for ( indx = 0; indx < *n; indx++ )
       work[msize + indx] = e[indx];
       
-      dsterf_(&msize, work, &work[msize], info);
+      ysterf_(&msize, work, &work[msize], info);
       
       for ( indx = 0; indx < *n; indx++ )
       eval[indx] = work[indx];
