@@ -572,10 +572,12 @@ int comex_fence_proc(int proc, comex_group_t group)
 /* comex_barrier is comex_fence_all + MPI_Barrier */
 int comex_barrier(comex_group_t group)
 {
+    int status;
     MPI_Comm comm;
 
     comex_fence_all(group);
-    assert(COMEX_SUCCESS == comex_group_comm(group, &comm));
+    status = comex_group_comm(group, &comm);
+    assert(COMEX_SUCCESS == status);
     MPI_Barrier(comm);
 
     return COMEX_SUCCESS;
@@ -1314,6 +1316,11 @@ int comex_malloc(void *ptrs[], size_t size, comex_group_t group)
     return COMEX_SUCCESS;
 }
 
+int comex_malloc_mem_dev(void *ptrs[], size_t size, comex_group_t group,
+        const char* device)
+{
+    return comex_malloc(ptrs,size,group);
+}
 
 int comex_free(void *ptr, comex_group_t group)
 {
@@ -1357,6 +1364,10 @@ int comex_free(void *ptr, comex_group_t group)
     return COMEX_SUCCESS;
 }
 
+int comex_free_dev(void *ptr, comex_group_t group)
+{
+    return comex_free(ptr, group);
+}
 
 static void acquire_remote_lock(int proc)
 {
@@ -1887,7 +1898,7 @@ static inline void nb_puts(
         src_idx = 0;
         dst_idx = 0;
         for(j=1; j<=stride_levels; j++) {
-            src_idx += src_bvalue[j] * src_stride[j-1];
+	  src_idx += (long) src_bvalue[j] * (long) src_stride[j-1];
             if((i+1) % src_bunit[j] == 0) {
                 src_bvalue[j]++;
             }
@@ -1897,7 +1908,7 @@ static inline void nb_puts(
         }
 
         for(j=1; j<=stride_levels; j++) {
-            dst_idx += dst_bvalue[j] * dst_stride[j-1];
+	  dst_idx += (long) dst_bvalue[j] * (long) dst_stride[j-1];
             if((i+1) % dst_bunit[j] == 0) {
                 dst_bvalue[j]++;
             }
@@ -1949,7 +1960,7 @@ static inline void nb_gets(
     for(i=0; i<n1dim; i++) {
         src_idx = 0;
         for(j=1; j<=stride_levels; j++) {
-            src_idx += src_bvalue[j] * src_stride[j-1];
+	  src_idx += (long) src_bvalue[j] * (long) src_stride[j-1];
             if((i+1) % src_bunit[j] == 0) {
                 src_bvalue[j]++;
             }
@@ -1961,7 +1972,7 @@ static inline void nb_gets(
         dst_idx = 0;
         
         for(j=1; j<=stride_levels; j++) {
-            dst_idx += dst_bvalue[j] * dst_stride[j-1];
+	  dst_idx += (long) dst_bvalue[j] * (long) dst_stride[j-1];
             if((i+1) % dst_bunit[j] == 0) {
                 dst_bvalue[j]++;
             }
@@ -2018,7 +2029,7 @@ static inline void nb_accs(
         src_idx = 0;
         dst_idx = 0;
         for(j=1; j<=stride_levels; j++) {
-            src_idx += src_bvalue[j] * src_stride[j-1];
+	  src_idx += (long) src_bvalue[j] * (long) src_stride[j-1];
             if((i+1) % src_bunit[j] == 0) {
                 src_bvalue[j]++;
             }
@@ -2028,7 +2039,7 @@ static inline void nb_accs(
         }
 
         for(j=1; j<=stride_levels; j++) {
-            dst_idx += dst_bvalue[j] * dst_stride[j-1];
+	  dst_idx += (long) dst_bvalue[j] * (long) dst_stride[j-1];
             if((i+1) % dst_bunit[j] == 0) {
                 dst_bvalue[j]++;
             }
