@@ -2,7 +2,7 @@
 #include "typesf2c.h"
 
 /* A fortran interface to memcpy since on at least one machine
-   (LINUX) dcopy() breaks when copying -ve integers even if
+   (LINUX) ycopy() breaks when copying -ve integers even if
    everything is correctly aligned. So you cannot copy common
    blocks or packed buffers, without doing the right thing  */
 
@@ -15,4 +15,4 @@ void FATR util_memcpy_(void *dest, void *src, Integer *n)
   memcpy(dest, src, (size_t) *n);
 }
 
-/* $Id: util_memcpy.c 26142 2014-09-03 00:26:20Z edo $ */
+/* $Id$ */
