@@ -1,5 +1,5 @@
 /*
- $Id: util_system.c 26142 2014-09-03 00:26:20Z edo $
+ $Id$
  */
 
 #include <stdio.h>
@@ -16,11 +16,6 @@ extern int system(const char *);
 #if defined(WIN32) && !defined(__MINGW32__)
 #include "typesf2c.h"
 #endif
-#if defined (DECOSF)
-#define __USE_BSD
-#include <signal.h>
-#undef __USE_BSD
-#endif
 
 void GA_Error(char *str, int code);
 
@@ -40,7 +35,7 @@ Integer FATR UTIL_SYSTEM(_fcd input)
 Integer util_system_(const char *input, int lin)
 {
 #endif
-#if (defined(LINUX) || defined(DECOSF)) && !defined(__x86_64__)
+#if defined(LINUX) && !defined(__x86_64__)
     int i;
 	void (*Siginit)();
 #endif
@@ -48,12 +43,7 @@ Integer util_system_(const char *input, int lin)
     if (!fortchar_to_string(input, lin, in, sizeof(in)))
 	GA_Error("util_system: fortchar_to_string failed for in",0);
 
-#if defined(DECOSF)
-	Siginit = signal(SIGCHLD,SIG_IGN);
-	i = system(in);
-	Siginit = signal(SIGCHLD,Siginit);
-    return i;
-#elif defined(CATAMOUNT)
+#if defined(CATAMOUNT)
     GA_Error("system calls do not work on this machine", 0);
 #else
     return system(in);
